<?php
/**
 * Necessary functions for theme
 *
 * @package skito
 */

namespace Skito\inc;

defined( 'ABSPATH' ) || die();

class Template_Tags {

    public function initial() {
        add_action( 'excerpt_more', [ $this, 'custom_excerpt_more' ] );
        add_action( 'wp_trim_excerpt', [ $this, 'excerpts_get_more_link' ] );
        add_action( 'excerpt_length', [ $this, 'custom_excerpt_length' ] );
    }

    /**
     * Remove Default Read More of Posts
     * add_action: excerpt_more
     *
     * @param $more
     *
     * @return string
     */
    public function custom_excerpt_more( $more ) {
        if ( ! is_admin() ) {
            $more = '';
        }
        return $more;
    }

    /**
     * Post Read More markup
     * add_action: wp_trim_excerpt
     *
     * @param $post_excerpt
     *
     * @return string
     */
    public function excerpts_get_more_link( $post_excerpt ) {
        if ( ! is_admin() ) {
            $post_excerpt = sprintf(
                '%s...<p class="post__content--excerpt--read-more"><a class="read-more-link" href="%s">%s</a></p>',
                $post_excerpt,
                esc_url( get_permalink( get_the_ID() ) ),
                __( 'Read More &#8594;', 'skito' )
            );
        }
        return $post_excerpt;
    }

    /**
     * Length of Post Excerpt
     * add_action: excerpt_length
     *
     * @param $length
     *
     * @return int
     */
    public function custom_excerpt_length( $length ) {
        if ( has_excerpt() && is_admin() ) {
            return $length;
        }
        return 20;
    }

    /**
     * Markup for Post Author
     *
     * @param int $size
     * @param string $class
     *
     * @return string
     */
    public static function get_post_author($size = 25, $class = 'skito-post__content--meta-avatar') {
        $author = sprintf(
            '<a href="%s" class=%s>%s</a>',
                    esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
                    esc_attr( $class ),
                    get_avatar( get_the_author_meta( 'ID' ), $size, '', get_the_author() )
                );
        return $author;
    }

    /**
     * Markup for Post date
     *
     * @param string $format
     * @param string $class
     *
     * @return string
     */
    public static function get_post_datetime($format = 'M d Y', $class = 'skito-post__content--meta-date') {
        $date = sprintf(
            '<div class=%s>%s</div>',
                    esc_attr( $class ),
                    esc_html( get_the_date( $format ) )
                );
        return $date;
    }

    /**
     * Markup for post category
     *
     * @param string $class
     *
     * @return string|void
     */
    public static function get_post_category($class = 'skito-post__content--meta-category') {
        if ( ! has_category() ) return;

        $category = get_the_category();
        $cat = sprintf(
                '<a href="%s" class="%s">%s</a>',
                    esc_url( get_category_link( $category[0]->term_id ) ),
                    esc_attr( $class ),
                    esc_html( $category[0]->name )
            );
        return $cat;
    }

    /**
     * Markup for post categories list
     *
     * @param string $class
     *
     * @return false|string|void
     */
    public static function get_post_categories($class = 'skito-single__meta-category') {
        if ( ! has_category() ) return;

        $categories = get_the_category();

        ob_start();
        foreach ( $categories as $cat ) {
             echo sprintf(
                '<a href="%s" class="%s">%s</a>',
                esc_url( get_category_link( $cat->term_id ) ),
                esc_attr( $class ),
                esc_html( $cat->name )
            );
        }
        return ob_get_clean();
    }

    /**
     * Execute wp_body_open
     * Mainly for backward compatibility
     */
    public static function body_open() {
        if ( ! function_exists( 'wp_body_open' ) ) {
            do_action( 'wp_body_open' );
        } else {
            wp_body_open();
        }
    }

    /**
     * Markup for Footer info
     *
     * @param string $link
     *
     * @return string
     */
    public static function site_info($link = 'https://wordpress.org/') {
        $info = sprintf(
            '%s<a href="%s" class="footer__into-link">%s</a>',
            __( 'Proudly powered by ', 'skito' ),
            esc_url( $link ),
            __( 'WordPress', 'skito' )
        );
        return $info;
    }

    /**
     * Checking the widget is active or not
     *
     * @param string $sidebar_id
     * @param string $has_sidebar
     * @param string $no_sidebar
     *
     * @return string
     */
    public static function sidebar_exist($sidebar_id = 'right-sidebar', $has_sidebar = 'has_sidebar', $no_sidebar = 'no_sidebar') {
        return is_active_sidebar( $sidebar_id ) ? $has_sidebar : $no_sidebar;
    }

    /**
     * Checking custom logo and add markup
     *
     * @param string $logo_class
     *
     * @return string
     */
    public static function theme_logo($logo_class = 'skito-logo') {

        if ( ! has_custom_logo() ) {
            $logo = sprintf (
                '<h1 class="%s"><a href="%s">%s</a></h1>',
                $logo_class,
                esc_url( home_url( '/' ) ),
                get_bloginfo( 'name' )
            );
        } else $logo = get_custom_logo();
        return $logo;
    }

    /**
     * Site Description
     * 
     * @param string $description_class
     *
     * @return string
     */
    public static function theme_description($description_class = 'skito-description') {
        $description = sprintf (
            '<div class="%s">%s</div>',
            $description_class,
            get_bloginfo( 'description' )
        );
        return $description;
    }

    /**
     * Post pagination markup
     *
     * @param array $args
     *
     * @return false|string|void
     */
    public static function custom_pagination( $args = [] ) {

        if ( $GLOBALS['wp_query']->max_num_pages <= 1 ) return;

        $defaults = [
            'mid_size'           => 2,
            'prev_next'          => true,
            'prev_text'          => esc_html('&#8592;' ),
            'next_text'          => esc_html( '&#8594;' ),
            'screen_reader_text' => __( 'Posts navigation', 'skito' ),
            'type'               => 'array',
            'current'            => max( 1, get_query_var('paged') ),
        ];
        $final_args = wp_parse_args( $args, $defaults );

        $links = paginate_links( $final_args );
        ob_start();
        ?>

        <nav class="skito-pagination" aria-label="<?php echo esc_attr( $args['screen_reader_text'] ); ?>">

            <ul class="skito-pagination__list">
                <?php foreach ( $links as $key => $link ) : ?>
                    <li class="skito-pagination__list-item <?php echo strpos( $link, 'current' ) ? 'active' : '' ?>">

                        <?php echo str_replace( 'page-numbers', 'page-link', $link ); ?>

                    </li>
                <?php endforeach; ?>
            </ul>

        </nav>
        <?php
        return ob_get_clean();
    }

    public static function post_nav() {
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous ) {
			return;
        }
        ob_start();
		?>
        <nav class="single-post-navigation">
            <h2 class="screen-reader-text"><?php _e( 'Post navigation', 'skito' ); ?></h2>
            <div class="nav-links">
                <?php
                    if ( get_previous_post_link() ) {
                        previous_post_link( '<span class="nav-previous">%link</span>', _x( '&larr; &nbsp;%title', 'Previous post', 'skito' ) );
                    }
                    if ( get_next_post_link() ) {
                        next_post_link( '<span class="nav-next">%link</span>', _x( '%title&nbsp; &rarr;', 'Next post', 'skito' ) );
                    }
                ?>
            </div>
        </nav>
        <?php
        return ob_get_clean();
	}

}